# Awesome KivyMD

Awesome KivyMD is a package containing customized and non-material widgets for KivyMD.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package:

```bash
# Latest version
pip install akivymd

# Latest changes 
pip install git+https://github.com/quitegreensky/akivymd.git
```

- In this case you must add the following to your ```buildozer.spec```
```
# Latest version
requirements =  kivy,kivymd, akivymd

# Latest changes 
requirements =  kivy,kivymd, git+https://github.com/quitegreensky/akivymd.git
```

## Usage

You can find usage examples in the demo app.
 
## Examples
<p style="text-align:center">
<img align="center" width="512" src="https://raw.githubusercontent.com/quitegreensky/akivymd/master/images/bottomnavigation.gif"/>
<img align="center" width="512" src="https://raw.githubusercontent.com/quitegreensky/akivymd/master/images/dataloader.gif"/>
<img align="center" width="512" src="https://raw.githubusercontent.com/quitegreensky/akivymd/master/images/piechart.gif"/>
<img align="center" width="512" src="https://raw.githubusercontent.com/quitegreensky/akivymd/master/images/spinners.gif"/>
</p>

## Contributing


## License
[MIT](https://choosealicense.com/licenses/mit/)